pub struct TermLink { /* private fields */ }Expand description
词项链
📄OpenNARS
A link between a compound term and a component term
A TermLink links the current Term to a target Term, which is either a component of, or compound made from, the current term.///
Neither of the two terms contain variable shared with other terms.///
The index value(s) indicates the location of the component in the compound.///
This class is mainly used in inference.RuleTable to dispatch premises to inference rules
Implementations
Sourceimpl TermLink
impl TermLink
pub fn from_template( target: Term, template: &TermLinkTemplate, budget: BudgetValue, ) -> Self